==> haskell-storable-tuple-0.0.3.3-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-tuple
version: 0.0.3.3
id: storable-tuple-0.0.3.3-9hxBspT73ldHbI4GZoAC3F
key: storable-tuple-0.0.3.3-9hxBspT73ldHbI4GZoAC3F
license: BSD-3-Clause
maintainer: Henning Thielemann <storable@henning-thielemann.de>
author: Henning Thielemann <storable@henning-thielemann.de>
stability: Experimental
homepage: http://code.haskell.org/~thielema/storable-tuple/
synopsis: Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
category: Data, Foreign
abi: 694762ff997da4ae23f0f5033df7fbbf
exposed: True
exposed-modules:
    Foreign.Storable.Tuple
import-dirs: /usr/lib/ghc-8.6.2/site-local/storable-tuple-0.0.3.3
library-dirs: /usr/lib/ghc-8.6.2/site-local/storable-tuple-0.0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/storable-tuple-0.0.3.3
hs-libraries: HSstorable-tuple-0.0.3.3-9hxBspT73ldHbI4GZoAC3F
depends:
    base-4.12.0.0 base-orphans-0.8-I5Wy5X7j4JPBlGRIrsmaA5
    storable-record-0.0.4-KSfqnxV0wCrDxvYLXFw5z3
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock
haddock-html: /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-tuple-0.0.3.3-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: storable-tuple
version: 0.0.3.3
id: storable-tuple-0.0.3.3-3tEc9RMVLdRJ4ABS1QETYS
key: storable-tuple-0.0.3.3-3tEc9RMVLdRJ4ABS1QETYS
license: BSD-3-Clause
maintainer: Henning Thielemann <storable@henning-thielemann.de>
author: Henning Thielemann <storable@henning-thielemann.de>
stability: Experimental
homepage: http://code.haskell.org/~thielema/storable-tuple/
synopsis: Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
category: Data, Foreign
abi: 36c41b8bb447124e034f3c063dfec0ba
exposed: True
exposed-modules:
    Foreign.Storable.Tuple
import-dirs: /usr/lib/ghc-8.6.3/site-local/storable-tuple-0.0.3.3
library-dirs: /usr/lib/ghc-8.6.3/site-local/storable-tuple-0.0.3.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/storable-tuple-0.0.3.3
hs-libraries: HSstorable-tuple-0.0.3.3-3tEc9RMVLdRJ4ABS1QETYS
depends:
    base-4.12.0.0 base-orphans-0.8-HC8rxCgWXMG2ghd5IcEIzb
    storable-record-0.0.4-KSfqnxV0wCrDxvYLXFw5z3
    utility-ht-0.0.14-BWOIGcMmaZCHGwnWSG1Ym4
haddock-interfaces: /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock
haddock-html: /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
